//
//  BaseViewController.m
//  Palmwms
//
//  Created by 曹云霄 on 16/8/24.
//  Copyright © 2016年 上海勾芒科技有限公司. All rights reserved.
//

#import "BaseViewController.h"
#import "MBProgressHUD.h"

@interface BaseViewController ()

/**
 *  加载动画
 */
@property (nonatomic,strong) MBProgressHUD *hud;

@end

@implementation BaseViewController

#pragma mark - lazy
- (MBProgressHUD *)hud
{
    if (!_hud) {
        _hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    }
    return _hud;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [self customAppStyle];
}

#pragma mark - 自定义风格
- (void)customAppStyle
{
    self.automaticallyAdjustsScrollViewInsets = NO;
    self.navigationController.navigationBar.translucent = NO;
    self.navigationController.navigationBar.barTintColor =  MainColor;
    [self.navigationController.navigationBar setTitleTextAttributes:@{NSFontAttributeName:[UIFont systemFontOfSize:17],NSForegroundColorAttributeName:[UIColor whiteColor]}];
}


#pragma mark - 自定义返回按钮
- (void)customBackButton:(SEL)backButtonClick
{
    UIBarButtonItem *backButton = [[UIBarButtonItem alloc]initWithImage:LOADIMAGENAME(@"back") style:UIBarButtonItemStyleDone target:self action:backButtonClick];
    self.navigationItem.leftBarButtonItem = backButton;
}




#pragma mark -渐隐提示框回调
- (void)SHOWPrompttext:(NSString *)Text ComcpleteBlock:(void(^)())completed
{
    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view.window animated:YES];
    hud.label.text = Text;
    hud.contentColor = MainColor;
    hud.label.font = [UIFont systemFontOfSize:12];
    hud.animationType = MBProgressHUDAnimationZoom;
    hud.mode = MBProgressHUDModeText;
    hud.removeFromSuperViewOnHide = YES;
    [hud hideAnimated:YES afterDelay:2.0];
    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(2 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
        if (completed) {
            completed();
        }
    });
}

#pragma mark -显示MBProgressHUD等待视图
- (void)CreateMBProgressHUDLoding
{
    self.hud.animationType = MBProgressHUDAnimationFade;
    self.hud.mode = MBProgressHUDModeIndeterminate;
    self.hud.contentColor = MainColor;
    self.hud.label.text = @"加载中";
    self.hud.label.font = [UIFont systemFontOfSize:12];
    self.hud.removeFromSuperViewOnHide = YES;
}


#pragma mark -进度条
- (void)ShowProgressView:(double)progress
{
    self.hud.mode = MBProgressHUDModeAnnularDeterminate;
    self.hud.label.text = @"上传中...";
    self.hud.label.font = [UIFont systemFontOfSize:12];
    self.hud.contentColor = MainColor;
    self.hud.progress = progress;
    self.hud.removeFromSuperViewOnHide = YES;
}

#pragma mark -移除MBProgressHUD等待视图
- (void)RemoveMBProgressHUDLoding
{
    [_hud hideAnimated:YES];
    _hud = nil;
}


#pragma mark -显示成功的提示框
- (void)SuccessMBProgressView:(NSString *)successString
{
    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    UIImage *image = [[UIImage imageNamed:@"Checkmark"] imageWithRenderingMode:UIImageRenderingModeAlwaysTemplate];
    UIImageView *imageView = [[UIImageView alloc] initWithImage:image];
    hud.customView = imageView;
    hud.label.textColor = MainColor;
    hud.label.font = [UIFont systemFontOfSize:12];
    hud.mode = MBProgressHUDModeCustomView;
    hud.label.text = successString;
    [hud hideAnimated:YES afterDelay:3.0];
}

#pragma mark -显示信息的提示框
- (void)ErrorMBProgressView:(NSString *)errorString
{
    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view.window animated:YES];
    UIImage *image = [[UIImage imageNamed:@"Checkmark"] imageWithRenderingMode:UIImageRenderingModeAlwaysTemplate];
    UIImageView *imageView = [[UIImageView alloc] initWithImage:image];
    hud.customView = imageView;
    hud.label.textColor = MainColor;
    hud.mode = MBProgressHUDModeCustomView;
    hud.label.font = [UIFont systemFontOfSize:12];
    hud.label.text = errorString;
    [hud hideAnimated:YES afterDelay:1.0];
}

#pragma mark -渐隐提示框
- (void)SHOWPrompttext:(NSString *)Text
{

    MBProgressHUD *hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    hud.mode = MBProgressHUDModeText;
    hud.label.text = Text;
    hud.contentColor = MainColor;
    hud.offset = CGPointMake(0.f, MBProgressMaxOffset);
    [hud hideAnimated:YES afterDelay:3.f];
}

#pragma mark -结束MJRfresh刷新
- (void)endRefreshingForTableView:(UIScrollView *)TableView
{
    if (TableView.mj_header.isRefreshing) {
        
        [TableView.mj_header endRefreshing];
    }
    else if (TableView.mj_footer.isRefreshing)
    {
        [TableView.mj_footer endRefreshing];
    }
}

#pragma mark -获得我的storyboard对象
- (UIStoryboard *)getStoryboardWithName
{
    UIStoryboard *storyboard = [UIStoryboard storyboardWithName:@"StoryboardwithCYX" bundle:nil];
    return storyboard;
}





@end
