//
//  palmwms_objc_json_client.h
//  Palmwms
//
//  Created by 曹云霄 on 16/8/24.
//  Copyright © 2016年 上海勾芒科技有限公司. All rights reserved.
//


#import <Foundation/Foundation.h>
#import "JSONModel.h"


/**
 *  排序方向。
 *
 *  @author Debenson
 *  @since 0.0.1
 */
/**
 * 升序
 */
extern NSString * const QUERYORDERDIRECTION_ASC;
/**
 * 降序
 */
extern NSString * const QUERYORDERDIRECTION_DESC;




@class QueryDefinition;
@class RsQueryResult;
@class Customer;
@class Driver;
@class LoginResult;
@class ResetPasswordRequest;
@class ModifyPasswordRequest;
@class LoginRequest;
@class QueryResultPaging;
@class QueryOrder;
@class RsResponse;
@class ExceptionCode;
@class CustomerQueryResult;
@class CustomerQueryDefintion;

@protocol QueryDefinition @end
@protocol RsQueryResult @end
@protocol Customer @end
@protocol Driver @end
@protocol LoginResult @end
@protocol ResetPasswordRequest @end
@protocol ModifyPasswordRequest @end
@protocol LoginRequest @end
@protocol QueryResultPaging @end
@protocol QueryOrder @end
@protocol RsResponse @end
@protocol ExceptionCode @end
@protocol CustomerQueryResult @end
@protocol CustomerQueryDefintion @end


/**
 *  查询定义。
 
 <br>
 查询定义的基类，具体查询条件由子类实现。
 
 @author Debenson
 @since 0.1
 
 */
@interface QueryDefinition : JSONModel
/**
 * 排序条件
 * @see QueryOrder
 *
 */
@property (nonatomic, strong) NSArray<QueryOrder> *orders;
/**
 * 页数，表示查询第几页
 *
 *
 */
@property (nonatomic, assign) NSInteger pageNumber;
/**
 * 每页的记录数，传0表示查询所有数据不分页
 *
 *
 */
@property (nonatomic, assign) NSInteger pageSize;
@end /* interface QueryDefinition */



/**
 *  查询结果。
 
 <br>
 查询结果基类， 具体结果集合由子类定义。
 
 @author Debenson
 @since 0.0.1
 
 */
@interface RsQueryResult : JSONModel
/**
 * 分页数据
 *
 *
 */
@property (nonatomic, strong) QueryResultPaging *paging;
/**
 * 当前页数
 *
 *
 */
@property (nonatomic, assign) NSInteger page;
/**
 * 每页记录数
 *
 *
 */
@property (nonatomic, assign) NSInteger pageSize;
/**
 * 总页数
 *
 *
 */
@property (nonatomic, assign) NSInteger pageCount;
/**
 * 总记录数
 *
 *
 */
@property (nonatomic, assign) long long recordCount;
@end /* interface RsQueryResult */



/**
 *  客户。
 
 @author Debenson
 @since 0.1
 
 */
@interface Customer : JSONModel
/**
 * 标识
 *
 *
 */
@property (nonatomic, copy) NSString *fid;
/**
 * 代码
 *
 *
 */
@property (nonatomic, copy) NSString *code;
/**
 * 名称
 *
 *
 */
@property (nonatomic, copy) NSString *name;
/**
 * 地址
 *
 *
 */
@property (nonatomic, copy) NSString *address;
/**
 * 经度
 *
 *
 */
@property (nonatomic, copy) NSString *lng;
/**
 * 纬度
 *
 *
 */
@property (nonatomic, copy) NSString *lat;
@end /* interface Customer */



/**
 *  司机
 
 @author Debenson
 @since 0.1
 
 */
@interface Driver : JSONModel
/**
 * 标识
 *
 *
 */
@property (nonatomic, copy) NSString *fid;
/**
 * 代码
 *
 *
 */
@property (nonatomic, copy) NSString *code;
/**
 * 名称
 *
 *
 */
@property (nonatomic, copy) NSString *name;
@end /* interface Driver */



/**
 *  登录结果。
 
 @author Debenson
 @since 0.1
 
 */
@interface LoginResult : JSONModel
/**
 * 司机信息
 *
 *
 */
@property (nonatomic, strong) Driver *driver;
@end /* interface LoginResult */



/**
 *  重置密码请求。
 
 @author Debenson
 @since 0.1
 
 */
@interface ResetPasswordRequest : JSONModel
/**
 * 用户编码
 *
 *
 */
@property (nonatomic, copy) NSString *code;
/**
 * 短信验证码，请先调用发送短信接口
 *
 *
 */
@property (nonatomic, copy) NSString *smsCode;
/**
 * 新密码
 *
 *
 */
@property (nonatomic, copy) NSString *fnewPassword;
@end /* interface ResetPasswordRequest */



/**
 *  修改密码请求。
 
 @author Debenson
 @since 0.1
 
 */
@interface ModifyPasswordRequest : JSONModel
/**
 * 司机标识。
 *
 *
 */
@property (nonatomic, copy) NSString *driverId;
/**
 * 原密码。
 *
 *
 */
@property (nonatomic, copy) NSString *oldPassword;
/**
 * 新密码
 *
 *
 */
@property (nonatomic, copy) NSString *fnewPassword;
@end /* interface ModifyPasswordRequest */



/**
 *  司机登录请求。
 
 @author Debenson
 @since 0.1
 
 */
@interface LoginRequest : JSONModel
/**
 * 用户名
 *
 *
 */
@property (nonatomic, copy) NSString *username;
/**
 * 密码
 *
 *
 */
@property (nonatomic, copy) NSString *password;
@end /* interface LoginRequest */



/**
 *  分页数据。
 
 @author Debenson
 @since 0.0.1
 
 */
@interface QueryResultPaging : JSONModel
/**
 * 当前页数，起始于0
 *
 *
 */
@property (nonatomic, assign) NSInteger page;
/**
 * 每页记录数，传0表示查询所有记录
 *
 *
 */
@property (nonatomic, assign) NSInteger pageSize;
/**
 * 查询结果总页数
 *
 *
 */
@property (nonatomic, assign) NSInteger pageCount;
/**
 * 查询结果总记录数
 *
 *
 */
@property (nonatomic, assign) long long recordCount;
@end /* interface QueryResultPaging */



/**
 *  查询排序条件。
 
 @author Debenson
 @since 0.0.1
 
 */
@interface QueryOrder : JSONModel
/**
 * 字段名称
 *
 *
 */
@property (nonatomic, copy) NSString *field;
/**
 * 排序方向
 *
 * 取值: QUERYORDERDIRECTION_ASC, QUERYORDERDIRECTION_DESC,
 */
@property (nonatomic, copy) NSString *direction;
@end /* interface QueryOrder */



/**
 *  Restful Service response base
 
 @author Debenson
 @since 0.1
 
 */
@interface RsResponse : JSONModel
/**
 * 0:正常， 非0异常。
 *
 *
 */
@property (nonatomic, assign) long long code;
/**
 * 异常描述
 *
 *
 */
@property (nonatomic, copy) NSString *message;
/**
 * 返回数据
 *
 *
 */
@property (nonatomic, strong) NSObject *data;
@end /* interface RsResponse */



/**
 *  异常代码。
 
 @author Debenson
 @since 0.1
 
 */
@interface ExceptionCode : JSONModel
/**
 * 异常代码
 *
 *
 */
@property (nonatomic, assign) NSInteger code;
/**
 * 异常信息
 *
 *
 */
@property (nonatomic, copy) NSString *message;
@end /* interface ExceptionCode */



/**
 *  客户查询结果。
 
 @author Debenson
 @since 0.1
 
 */
@interface CustomerQueryResult : RsQueryResult
/**
 * 查询结果集合
 * @see RsQueryResult
 *
 */
@property (nonatomic, strong) NSArray<RsQueryResult> *records;
@end /* interface CustomerQueryResult */



/**
 *  客户查询定义。
 
 @author Debenson
 @since 0.1
 
 */
@interface CustomerQueryDefintion : QueryDefinition
/**
 * (no documentation provided)
 *
 *
 */
@property (nonatomic, copy) NSString *codeEqualsOrNameLike;
@end /* interface CustomerQueryDefintion */


